@@ -77,7 +77,7 @@ class Remote:
         self.user_branch: user for head branch of pull-request.
     """
 
-    def __init__(self, remote_name:str="", repo_branch:str="", local_branch:str="", repo:RepositoryID=None, git:Git=None, gh_repo:Repository=None, config=True, fork=False, on_local=True,sync_merge=False):
+    def __init__(self, remote_name:str="", repo_branch:str="", local_branch:str="", repo:RepositoryID=None, git:Git=None, gh_repo:Repository=None, config=True, fork=False, on_local=True,sync_merge=False,quick_commit=True):
         self._gh_repo = None 
         self._repo = None
         self.user = ""
@@ -85,6 +85,7 @@ class Remote:
         self.fork =fork
         self.on_local=on_local
         self.sync_merge=sync_merge
+        self.quick_commit=quick_commit
         # TODO0 set the value int git.config
         self.remote_name = remote_name
         self.repo_branch = repo_branch
@@ -93,7 +94,7 @@ class Remote:
         # set property attr
         self.repo = repo
         self.gh_repo = gh_repo
-
+        
         self.copy_option_list = ["user", "remote_name", "repo_branch", "local_branch", "git", "repo", "gh_repo"]
         
      
@@ -126,7 +127,6 @@ class Remote:
             self.set_into_git()
 
     def addRemote(self, other:"Remote"):
-        
         for attr in other.__dict__:
             if attr in self.copy_option_list:
                 self.__dict__[attr] =  self.__dict__[attr] or other.__dict__[attr]
@@ -170,17 +170,36 @@ class Remote:
     def pull(self):
         if not self.exist_repo_branches(self.repo_branch):
             logger.info(f"Because of missing of {self.repo.repo}/{self.repo_branch}, fetching")
-    
-        if self.sync_merge:
-            sync = self.git.merge
-            linter = ["merging", "git add .; git commit", "git merge --abort"]
-        else:
-            sync = self.git.rebase
-            linter = ["rebasing", "git add .; git rebase -- continue", "git rebase --abort"]
-
         self.git.fetch_branch(self.remote_name, self.repo_branch)
+        if self.sync_merge:
+            self.merge()
+            action = "Merge"
+        else:
+            self.rebase()
+            action = "Rebase"
+        logger.success(f"{action} success from {self.remote_branch} to {self.local_branch}")
+
+    def rebase(self):
+        linter = ["rebasing", "git add .; git rebase -- continue", "git rebase --abort"]
         try:
-            sync(self.remote_branch, self.local_branch)
+            self.git.rebase(self.remote_branch, self.local_branch)
+        except RuntimeError:
+            logger.error(
+                f"During the {linter[0]} {self.local_branch} from {self.remote_branch}, "
+                "it is likely that your change has a merge conflict. "
+                f"You may resolve it by `{linter[1]}`"
+                "Once done run `git pull-request' again. "
+                f"If you want to abort conflict resolution, run `{linter[2]}`."
+            )
+            dead_for_resource()
+
+    def merge(self):
+        linter = ["merging", "git add .; git commit", "git merge --abort"]
+        try:
+            if self.quick_commit:
+                self.git.quickMerge(self.remote_branch, self.local_branch, ours=True if self.quick_commit == "ours" else False)
+            else:
+                self.git.merge(self.remote_branch, self.local_branch)
         except RuntimeError:
             logger.error(
                 f"During the {linter[0]} {self.local_branch} from {self.remote_branch}, "
@@ -193,10 +212,11 @@ class Remote:
 
     def push(self, ignore_error=False, retry=3, timeout=45):
         self.git.push(self.remote_name, self.local_branch, self.repo_branch, ignore_error=ignore_error, retry=retry, timeout=timeout)
-    
+        logger.success(f"Push success from {self.local_branch} to {self.repo_branch}")
+
     def __str__(self):
         return " ".join([item + ": \'" + str(self.__dict__[item]) + "\'"for item in self.__dict__ if item != "git"])
-
+    
 
 class Auto:
     """ 
@@ -220,7 +240,8 @@ class Auto:
         labels=None,
         skip_editor="",
         token="",
-        sync_merge=False,):
+        sync_merge=False,
+        quick_commit="false"):
         self.git = Git()
         self.content = PRContent(title, body)
         self.keep_message = keep_message
@@ -238,6 +259,7 @@ class Auto:
             fork=False,
             on_local=True if not target_url else False,
             sync_merge=sync_merge,
+            quick_commit=quick_commit,
         )
         self.fork_remote = Remote(
             git = self.git,
@@ -247,6 +269,7 @@ class Auto:
             fork=True,
             on_local=True if not fork_url else False,
             sync_merge=sync_merge,
+            quick_commit=quick_commit,
         )
         logger.info(f"accepted option parameters. \ntarget_remote: {self.target_remote}\nfork_remote: {self.fork_remote}\n")
         
